@@ -18,6 +18,7 @@ __all__ = [
     'display', 'print'
 ]
 
+print_py = print
 from rich import print
 import glob, numpy as np, pandas as pd, tqdm, os, sys, re
 from IPython.display import display
@@ -71,8 +72,9 @@ class Timer:
 
     def __call__(self, ix=None, info=None):
         ix = self.ix if ix is None else ix
+        info = '' if info is None else f'{info}\t'
         elapsed = time.time() - self.start
-        print('\r{}\t{}/{} ({:.2f}s - {:.2f}s remaining)'.format(info, ix+1, self.N, elapsed, (self.N-ix)*(elapsed/(ix+1))), end='')
+        print_py('{}{}/{} ({:.2f}s - {:.2f}s remaining)'.format(info, ix+1, self.N, elapsed, (self.N-ix)*(elapsed/(ix+1))), end='\r')
         self.ix += 1
 
 old_line = lambda N=66: print('='*N)
